==> qtwebengine-everywhere-opensource-src-6.2.5.zip: qtwebengine-everywhere-src-6.2.5/src/3rdparty/chromium/components/autofill/core/browser/ui/popup_item_ids.h <==
// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// This enum defines item identifiers for Autofill popup controller.

#ifndef COMPONENTS_AUTOFILL_CORE_BROWSER_UI_POPUP_ITEM_IDS_H_
#define COMPONENTS_AUTOFILL_CORE_BROWSER_UI_POPUP_ITEM_IDS_H_

namespace autofill {

// GENERATED_JAVA_ENUM_PACKAGE: org.chromium.components.autofill
// GENERATED_JAVA_PREFIX_TO_STRIP: POPUP_
enum PopupItemId {
  POPUP_ITEM_ID_AUTOCOMPLETE_ENTRY = 0,
  POPUP_ITEM_ID_INSECURE_CONTEXT_PAYMENT_DISABLED_MESSAGE = -1,
  POPUP_ITEM_ID_PASSWORD_ENTRY = -2,
  POPUP_ITEM_ID_SEPARATOR = -3,
  POPUP_ITEM_ID_CLEAR_FORM = -4,
  POPUP_ITEM_ID_AUTOFILL_OPTIONS = -5,
  POPUP_ITEM_ID_DATALIST_ENTRY = -6,
  POPUP_ITEM_ID_SCAN_CREDIT_CARD = -7,
  POPUP_ITEM_ID_TITLE = -8,
  POPUP_ITEM_ID_CREDIT_CARD_SIGNIN_PROMO = -9,
  POPUP_ITEM_ID_USERNAME_ENTRY = -11,
  POPUP_ITEM_ID_ALL_SAVED_PASSWORDS_ENTRY = -13,
  POPUP_ITEM_ID_GENERATE_PASSWORD_ENTRY = -14,
  POPUP_ITEM_ID_SHOW_ACCOUNT_CARDS = -15,
  POPUP_ITEM_ID_PASSWORD_ACCOUNT_STORAGE_OPT_IN = -16,
  POPUP_ITEM_ID_HIDE_AUTOFILL_SUGGESTIONS = -17,
  POPUP_ITEM_ID_USE_VIRTUAL_CARD = -18,
  POPUP_ITEM_ID_PASSWORD_ACCOUNT_STORAGE_OPT_IN_AND_GENERATE = -21,
  POPUP_ITEM_ID_ACCOUNT_STORAGE_PASSWORD_ENTRY = -22,
  POPUP_ITEM_ID_ACCOUNT_STORAGE_USERNAME_ENTRY = -23,
  POPUP_ITEM_ID_PASSWORD_ACCOUNT_STORAGE_RE_SIGNIN = -24,
  POPUP_ITEM_ID_PASSWORD_ACCOUNT_STORAGE_EMPTY = -25,
  POPUP_ITEM_ID_MIXED_FORM_MESSAGE = -26,
  POPUP_ITEM_ID_VIRTUAL_CREDIT_CARD_ENTRY = -27
};

}  // namespace autofill

#endif  // COMPONENTS_AUTOFILL_CORE_BROWSER_UI_POPUP_ITEM_IDS_H_

==> qtwebengine-everywhere-opensource-src-6.5.4.zip: qtwebengine-everywhere-src-6.5.4/src/3rdparty/chromium/components/autofill/core/browser/ui/popup_item_ids.h <==
// Copyright 2014 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// This enum defines item identifiers for Autofill popup controller.

#ifndef COMPONENTS_AUTOFILL_CORE_BROWSER_UI_POPUP_ITEM_IDS_H_
#define COMPONENTS_AUTOFILL_CORE_BROWSER_UI_POPUP_ITEM_IDS_H_

namespace autofill {

// GENERATED_JAVA_ENUM_PACKAGE: org.chromium.components.autofill
// GENERATED_JAVA_PREFIX_TO_STRIP: POPUP_
enum PopupItemId {
  POPUP_ITEM_ID_AUTOCOMPLETE_ENTRY = 0,
  POPUP_ITEM_ID_INSECURE_CONTEXT_PAYMENT_DISABLED_MESSAGE = -1,
  POPUP_ITEM_ID_PASSWORD_ENTRY = -2,
  POPUP_ITEM_ID_SEPARATOR = -3,
  POPUP_ITEM_ID_CLEAR_FORM = -4,
  POPUP_ITEM_ID_AUTOFILL_OPTIONS = -5,
  POPUP_ITEM_ID_DATALIST_ENTRY = -6,
  POPUP_ITEM_ID_SCAN_CREDIT_CARD = -7,
  POPUP_ITEM_ID_TITLE = -8,
  POPUP_ITEM_ID_CREDIT_CARD_SIGNIN_PROMO = -9,
  POPUP_ITEM_ID_USERNAME_ENTRY = -11,
  POPUP_ITEM_ID_ALL_SAVED_PASSWORDS_ENTRY = -13,
  POPUP_ITEM_ID_GENERATE_PASSWORD_ENTRY = -14,
  POPUP_ITEM_ID_SHOW_ACCOUNT_CARDS = -15,
  POPUP_ITEM_ID_PASSWORD_ACCOUNT_STORAGE_OPT_IN = -16,
  POPUP_ITEM_ID_USE_VIRTUAL_CARD = -18,
  POPUP_ITEM_ID_PASSWORD_ACCOUNT_STORAGE_OPT_IN_AND_GENERATE = -21,
  POPUP_ITEM_ID_ACCOUNT_STORAGE_PASSWORD_ENTRY = -22,
  POPUP_ITEM_ID_ACCOUNT_STORAGE_USERNAME_ENTRY = -23,
  POPUP_ITEM_ID_PASSWORD_ACCOUNT_STORAGE_RE_SIGNIN = -24,
  POPUP_ITEM_ID_PASSWORD_ACCOUNT_STORAGE_EMPTY = -25,
  POPUP_ITEM_ID_MIXED_FORM_MESSAGE = -26,
  POPUP_ITEM_ID_VIRTUAL_CREDIT_CARD_ENTRY = -27,
  POPUP_ITEM_ID_WEBAUTHN_CREDENTIAL = -28,
  POPUP_ITEM_ID_MERCHANT_PROMO_CODE_ENTRY = -29,
  POPUP_ITEM_ID_SEE_PROMO_CODE_DETAILS = -30,
  POPUP_ITEM_ID_WEBAUTHN_SIGN_IN_WITH_ANOTHER_DEVICE = -31,
  POPUP_ITEM_ID_IBAN_ENTRY = -32,
};

// List of `PopupItemId` that trigger filling a value into an input element
// when the user selects the `PopupItemId`.
constexpr PopupItemId kItemsTriggeringFieldFilling[] = {
    POPUP_ITEM_ID_AUTOCOMPLETE_ENTRY,
    POPUP_ITEM_ID_PASSWORD_ENTRY,
    POPUP_ITEM_ID_DATALIST_ENTRY,
    POPUP_ITEM_ID_USERNAME_ENTRY,
    POPUP_ITEM_ID_ACCOUNT_STORAGE_PASSWORD_ENTRY,
    POPUP_ITEM_ID_ACCOUNT_STORAGE_USERNAME_ENTRY,
    POPUP_ITEM_ID_VIRTUAL_CREDIT_CARD_ENTRY,
    POPUP_ITEM_ID_MERCHANT_PROMO_CODE_ENTRY};

}  // namespace autofill

#endif  // COMPONENTS_AUTOFILL_CORE_BROWSER_UI_POPUP_ITEM_IDS_H_
